@@ -4,7 +4,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  *
- * @version   $Id: utils.php.patched,v 1.1.2.1 2002/11/30 09:57:57 cbayle Exp $
+ * @version   $Id: utils.php,v 1.47.2.3 2006/05/11 19:32:13 danper Exp $
  *
  * This file is part of GForge.
  *
@@ -25,8 +25,8 @@
 
 
 /**
- * removeCRLF() - remove any Cariage Return-Line Feed from a string. 
- * That function is usefull to remove the possibility of a CRLF Injection when sending mail
+ * removeCRLF() - remove any Carriage Return-Line Feed from a string. 
+ * That function is useful to remove the possibility of a CRLF Injection when sending mail
  * All the data that we will send should be passed through that function
  *
  * @param	   string  The string that we want to empty from any CRLF 
@@ -84,9 +84,8 @@ function util_check_fileupload($filename) {
  * @param		string	The optional email sender name. Defaults to ''
  *
  */
-function util_send_message($to,$subject,$body,$from='',$BCC='',$sendername='') {
-	global $Language;
-	global $sys_sendmail_path;
+function util_send_message($to,$subject,$body,$from='',$BCC='',$sendername='',$extra_headers='') {
+	global $Language,$sys_bcc_all_email_address,$sys_sendmail_path;
 
 	if (!$to) {
 		$to='noreply@'.$GLOBALS['sys_default_domain'];
@@ -94,12 +93,25 @@ function util_send_message($to,$subject,$body,$from='',$BCC='',$sendername='') {
 	if (!$from) {
 		$from='noreply@'.$GLOBALS['sys_default_domain'];
 	}
+	
 
 	$charset = $Language->getText('conf','mail_charset');
-	$body = "To: $to".
-		"\nFrom: ".util_encode_mailaddr($from,$sendername,$charset).
-		"\nBCC: $BCC".
-		"\nSubject: ".util_encode_mimeheader($subject, $charset).
+	if (!$charset) {
+		$charset = 'UTF-8';
+	}
+	$body2 = '';
+	if ($extra_headers) {
+		$body2 .= $extra_headers."\n";
+	}
+	$body2 .= "To: $to".
+		"\nFrom: ".util_encode_mailaddr($from,$sendername,$charset);
+	if (!empty($sys_bcc_all_email_address)) {
+		$BCC.=",$sys_bcc_all_email_address";
+	}
+	if(!empty($BCC)) {
+		$body2 .= "\nBCC: $BCC";
+	}
+	$body2 .= "\nSubject: ".util_encode_mimeheader($subject, $charset).
 		"\nContent-type: text/plain; charset=$charset".
 		"\n\n".
 		util_convert_body($body, $charset);
@@ -108,8 +120,15 @@ function util_send_message($to,$subject,$body,$from='',$BCC='',$sendername='') {
 		$sys_sendmail_path="/usr/sbin/sendmail";
 	}
 
-	exec ("/bin/echo \"". util_prep_string_for_sendmail($body) .
-		  "\" | ".$sys_sendmail_path." -f'$from' -t -i > /dev/null 2>&1 &");
+	exec ("/bin/echo \"". util_prep_string_for_sendmail($body2) .
+		  "\" | ".$sys_sendmail_path." -f'$from' -t -i > /dev/null 2>&1 &");	
+// WARNING : popen commented code probably brought some trouble, we will use the pipe method as we were before		  
+/*       if (!$handle = popen($sys_sendmail_path." -f'$from' -t -i", "w")) {
+               echo "<p>Error: cannot run '$sys_sendmail_path' - mail not sent</p>\n";
+       } else {
+               fwrite($handle, util_prep_string_for_sendmail($body2));
+               pclose($handle);
+       }*/
 }
 
 /**
@@ -159,10 +178,10 @@ function util_encode_mimeheader($str,$charset) {
  *
  */
 function util_convert_body($str,$charset) {
-	if (!function_exists('mb_convert_encoding')) {
+	if (!function_exists('mb_convert_encoding') || $charset == 'UTF-8') {
 		return $str;
 	}
-
+	
 	return mb_convert_encoding($str,$charset,"UTF-8");
 }
 
@@ -225,8 +244,9 @@ function util_prep_string_for_sendmail($body) {
  *	@param	string	the message body
  *	@param	string	a comma-separated list of email address
  *	@param	string	a comma-separated list of jabber address
+ *	@param	string	From header
  */
-function util_handle_message($id_arr,$subject,$body,$extra_emails='',$extra_jabbers='') {
+function util_handle_message($id_arr,$subject,$body,$extra_emails='',$extra_jabbers='',$from='') {
 	$address=array();
 
 	if (count($id_arr) < 1) {
@@ -261,7 +281,7 @@ function util_handle_message($id_arr,$subject,$body,$extra_emails='',$extra_jabb
 		}
 	}
 	if ($extra_email1 || $extra_emails) {
-		util_send_message('',$subject,$body,'',$extra_email1.$extra_emails);
+		util_send_message('',$subject,$body,$from,$extra_email1.$extra_emails);
 	}
 	if ($extra_jabber1 || $extra_jabbers) {
 		util_send_jabber($extra_jabber1.$extra_jabbers,$subject,$body);
@@ -426,9 +446,11 @@ function util_line_wrap ($text, $wrap = 80, $break = "\n") {
  *
  */
 function util_make_links ($data='') {
-	if(empty($data)) { return $data; }
-
+	if(empty($data)) { 
+		return $data; 
+	}
 	$lines = split("\n",$data);
+	$newText = "";
 	while ( list ($key,$line) = each ($lines)) {
 		// When we come here, we usually have form input
 		// encoded in entities. Our aim is to NOT include
@@ -454,7 +476,7 @@ function show_priority_colors_key() {
 
 		<table border="0"><tr>';
 
-	for ($i=1; $i<10; $i++) {
+	for ($i=1; $i<6; $i++) {
 		echo '
 			<td bgcolor="'.html_get_priority_color($i).'">'.$i.'</td>';
 	}
@@ -628,58 +650,82 @@ Function GraphIt($name_string,$value_string,$title) {
  * ShowResultSet() - Show a generic result set
  * Very simple, plain way to show a generic result set
  *
- * @param		int		The result set ID
- * @param		string	The title of the result set
- * @param		bool	The option to turn URL's into links
+ * @param	int		The result set ID
+ * @param	string	The title of the result set
+ * @param	bool	The option to turn URL's into links
+ * @param	bool	The option to display headers
+ * @param	array	The db field name -> label mapping
+ * @param	array   Don't display these cols
  *
  */
-function  ShowResultSet($result,$title="Untitled",$linkify=false)  {
+function ShowResultSet($result,$title='',$linkify=false,$displayHeaders=true,$headerMapping=array(), $excludedCols=array())  {
 	global $group_id,$HTML;
 
-	if  ($result)  {
+	if($result)  {
 		$rows  =  db_numrows($result);
 		$cols  =  db_numfields($result);
 
-		echo '
-			<table border="0" width="100%">';
-
-		/*  Create the title  */
-
-		$cell_data=array();
-		$cell_data[] = array($title, 'colspan="'.$cols.'"');
-		echo $HTML->multiTableRow('',$cell_data, TRUE);
+		echo '<table border="0" width="100%">';
 
 		/*  Create  the  headers  */
-		$cell_data=array();
+		$headersCellData = array();
+		$colsToKeep = array();
 		for ($i=0; $i < $cols; $i++) {
-			$cell_data[] = array(db_fieldname($result,$i));
+			$fieldName = db_fieldname($result, $i);
+			if(in_array($fieldName, $excludedCols)) {
+				continue;
+			}
+			$colsToKeep[] = $i;
+			if(isset($headerMapping[$fieldName])) {
+				if(is_array($headerMapping[$fieldName])) {
+					$headersCellData[] = $headerMapping[$fieldName];
+				} else {
+					$headersCellData[] = array($headerMapping[$fieldName]);
+				}
+			}
+			else {
+				$headersCellData[] = array($fieldName);
+			}
+		}
+		
+		/*  Create the title  */
+		if(strlen($title) > 0) {
+			$titleCellData = array();
+			$titleCellData[] = array($title, 'colspan="'.count($headersCellData).'"');
+			echo $HTML->multiTableRow('', $titleCellData, TRUE);
+		}
+		
+		/* Display the headers */
+		if($displayHeaders) {
+			echo $HTML->multiTableRow('', $headersCellData, TRUE);
 		}
-		echo $HTML->multiTableRow('',$cell_data, TRUE);
 
 		/*  Create the rows  */
-		for ($j = 0; $j < $rows; $j++) {
+ 		for ($j = 0; $j < $rows; $j++) {
 			echo '<tr '. $HTML->boxGetAltRowStyle($j) . '>';
 			for ($i = 0; $i < $cols; $i++) {
-				if ($linkify && $i == 0) {
-					$link = '<a href="'.$PHP_SELF.'?';
-					$linkend = '</a>';
-					if ($linkify == "bug_cat") {
-						$link .= 'group_id='.$group_id.'&amp;bug_cat_mod=y&amp;bug_cat_id='.db_result($result, $j, 'bug_category_id').'">';
-					} else if($linkify == "bug_group") {
-						$link .= 'group_id='.$group_id.'&amp;bug_group_mod=y&amp;bug_group_id='.db_result($result, $j, 'bug_group_id').'">';
-					} else if($linkify == "patch_cat") {
-						$link .= 'group_id='.$group_id.'&amp;patch_cat_mod=y&amp;patch_cat_id='.db_result($result, $j, 'patch_category_id').'">';
-					} else if($linkify == "support_cat") {
-						$link .= 'group_id='.$group_id.'&amp;support_cat_mod=y&amp;support_cat_id='.db_result($result, $j, 'support_category_id').'">';
-					} else if($linkify == "pm_project") {
-						$link .= 'group_id='.$group_id.'&amp;project_cat_mod=y&amp;project_cat_id='.db_result($result, $j, 'group_project_id').'">';
+				if(in_array($i, $colsToKeep)) {
+					if ($linkify && $i == 0) {
+						$link = '<a href="'.$PHP_SELF.'?';
+						$linkend = '</a>';
+						if ($linkify == "bug_cat") {
+							$link .= 'group_id='.$group_id.'&amp;bug_cat_mod=y&amp;bug_cat_id='.db_result($result, $j, 'bug_category_id').'">';
+						} else if($linkify == "bug_group") {
+							$link .= 'group_id='.$group_id.'&amp;bug_group_mod=y&amp;bug_group_id='.db_result($result, $j, 'bug_group_id').'">';
+						} else if($linkify == "patch_cat") {
+							$link .= 'group_id='.$group_id.'&amp;patch_cat_mod=y&amp;patch_cat_id='.db_result($result, $j, 'patch_category_id').'">';
+						} else if($linkify == "support_cat") {
+							$link .= 'group_id='.$group_id.'&amp;support_cat_mod=y&amp;support_cat_id='.db_result($result, $j, 'support_category_id').'">';
+						} else if($linkify == "pm_project") {
+							$link .= 'group_id='.$group_id.'&amp;project_cat_mod=y&amp;project_cat_id='.db_result($result, $j, 'group_project_id').'">';
+						} else {
+							$link = $linkend = '';
+						}
 					} else {
 						$link = $linkend = '';
 					}
-				} else {
-					$link = $linkend = '';
+					echo '<td>'.$link . db_result($result,  $j,  $i) . $linkend.'</td>';
 				}
-				echo '<td>'.$link . db_result($result,  $j,  $i) . $linkend.'</td>';
 			}
 			echo '</tr>';
 		}
@@ -700,6 +746,30 @@ function validate_email ($address) {
 	return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address));
 }
 
+/**
+ * validate_emails() - Validate a list of e-mail addresses
+ *
+ * @param	string	E-mail list
+ * @param	char	Separator
+ * @returns	array	Array of invalid e-mail addresses (if empty, all addresses are OK)
+*/
+function validate_emails ($addresses, $separator=',') {
+	if (strlen($addresses) == 0) return array();
+	
+	$emails = explode($separator, $addresses);
+	$ret 	= array();
+	
+	if (is_array($emails)) {
+		foreach ($emails as $email) {
+			$email = trim($email);		// This is done so we can validate lists like "a@b.com, c@d.com"
+			if (!validate_email($email)) $ret[] = $email;
+		}
+	}
+	return $ret;
+}
+
+
+
 /**
  * util_is_valid_filename() - Verifies whether a file has a valid filename
  *
@@ -753,4 +823,101 @@ function valid_hostname ($hostname = "xyz") {
 
 }
 
-?>
+
+/**
+ * human_readable_bytes() - Translates an integer representing bytes to a human-readable format.
+ *
+ * Format file size in a human-readable way
+ * such as "xx Megabytes" or "xx Mo"
+ *
+ * @author           Andrea Paleni <andreaSPAMLESS_AT_SPAMLESScriticalbit.com>
+ * @version        1.0
+ * @param int       bytes   is the size
+ * @param bool     base10  enable base 10 representation, otherwise
+ *                 default base 2  is used  
+ * @param int       round   number of fractional digits
+ * @param array     labels  strings associated to each 2^10 or
+ *                  10^3(base10==true) multiple of base units
+ */
+function human_readable_bytes ($bytes, $base10=false, $round=0, $labels=array(' bytes',  ' KB', ' MB', ' GB')) {
+	if ($bytes <= 0 || !is_array($labels) || (count($labels) <= 0)) {
+		return null;
+	}
+	$step = $base10 ? 3 : 10;
+	$base = $base10 ? 10 : 2;
+	$log = (int)(log10($bytes)/log10($base));
+	krsort($labels);
+	foreach ($labels as $p=>$lab) {
+		$pow = $p * $step;
+		if ($log < $pow) {
+			continue;
+		}
+		if ($lab == " MB") {
+			$round = 2;
+		}
+		$text = round($bytes/pow($base,$pow),$round).$lab;
+		break;
+	}
+	return $text;
+}
+
+/**
+ *	ls - lists a specified directory and returns an array of files
+ *	@param	string	the path of the directory to list
+ *	@param	boolean	whether to filter out directories and illegal filenames
+ *	@return	array	array of file names.
+ */
+function &ls($dir,$filter=false) {
+	exec('ls -c1 '.$dir,$out);
+	if ($filter) {
+		for ($i=0; $i<count($out); $i++) {
+			if (util_is_valid_filename($out[$i]) && is_file($dir.'/'.$out[$i])) {
+				$filtered[]=$out[$i];
+			}
+		}
+		return $filtered;
+	} else {
+		return $out;
+	}
+}
+
+/**
+ * readfile_chunked() - replacement for readfile
+ *
+ * @param		string	The file path
+ * @param		bool    Whether to return bytes served or just a bool
+ *
+ */
+function readfile_chunked($filename, $returnBytes=true) {
+    $chunksize = 1*(1024*1024); // 1MB chunks
+    $buffer = '';
+    $byteCounter = 0;
+    
+    $handle = fopen($filename, 'rb');
+    if ($handle === false) {
+        return false;
+    }
+    
+    while (!feof($handle)) {
+        $buffer = fread($handle, $chunksize);
+        echo $buffer;
+        if ($returnBytes) {
+            $byteCounter += strlen($buffer);
+		}
+    }
+    $status = fclose($handle);
+    if ($returnBytes && $status) {
+        return $byteCounter; // return num. bytes delivered like readfile() does.
+    }
+    return $status;
+}
+
+/**
+ * util_is_root_dir() - Checks if a directory points to the root dir
+ * @param	string	Directory
+ * @return bool
+ */
+function util_is_root_dir($dir) {
+	return !preg_match('/[^\\/]/',$dir);
+}
+?>
\ No newline at end of file
