@@ -3,7 +3,7 @@
 /**
  * Copyright 1999-2001 (c) VA Linux Systems
  *
- * @version   $Id: rotate_activity.php,v 1.8 2001/06/13 18:44:09 pfalcon Exp $
+ * @version   $Id: rotate_activity.php,v 1.8 2004/07/26 20:27:56 cbayle Exp $
  *
  * This file is part of GForge.
  *
@@ -23,18 +23,22 @@
  */
 
 require ('squal_pre.php');
+require ('common/include/cron_utils.php');
 
 $today_formatted=date('Ymd',(time()-(30*60*60*24)));
+$sql='';
 
 db_begin();
 
-$sql = "DELETE FROM activity_log WHERE day < '$today_formatted'";
-echo $sql;
+$sql = "DELETE FROM activity_log WHERE day < $today_formatted";
+$err .= $sql;
 $rel = db_query($sql);
-echo db_error();
+$err .= db_error();
 
 db_commit();
 
-echo "Done: ".date('Ymd H:i').' - '.db_error();
+$err .= " Done: ".date('Ymd H:i').' - '.db_error();
+
+cron_entry(10,$err);
 
 ?>
