@@ -5,7 +5,7 @@
  *
  * Copyright 1999-2001 (c) VA Linux Systems
  *
- * @version   $Id: vacuum.php,v 1.4 2001/05/10 00:58:34 jbyers Exp $
+ * @version   $Id: vacuum.php,v 1.8 2005/03/04 22:05:04 gsmet Exp $
  *
  * This file is part of GForge.
  *
@@ -25,6 +25,7 @@
  */
 
 require ('squal_pre.php');
+require ('common/include/cron_utils.php');
 
 //
 //	PG 7.1 and earlier
@@ -33,11 +34,13 @@ require ('squal_pre.php');
 //
 //	PG 7.2 and 7.3
 //
-$res = db_query("VACUUM FULL;");
+$res = db_query("VACUUM FULL ANALYZE;");
 
 
 if (!$res) {
-	echo "Error on DB1: " . db_error();
+	$err .= "Error on DB1: " . db_error();
 }
 
+cron_entry(12,$err);
+
 ?>
