@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: mailing_lists_dump.pl,v 1.3 2000/10/11 19:55:39 tperdue Exp $
+# $Id: mailing_lists_dump.pl,v 1.3 2005/03/03 21:38:26 cbayle Exp $
 #
 # mailing_list_dump.pl - Script to suck data outta the database to be processed on the mail
 #                        mail server to create mailing lists
@@ -25,4 +25,4 @@ while(my ($list_name, $list_admin, $password, $status) = $c->fetchrow()) {
 
 
 # Now write out the files
-write_array_file($file_dir."list_dump", @list_array);
+write_array_file($file_dir."/list_dump", @list_array);
