@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: ssh_dump_2_5.pl,v 1.1 2001/11/02 11:43:06 cbayle Exp $
+# $Id: ssh_dump.pl,v 1.8 2005/03/03 21:38:26 cbayle Exp $
 #
 # ssh_dump.pl - Script to suck data outta the database to be processed by ssh_create.pl
 #
@@ -22,4 +22,4 @@ while(my ($username, $unix_uid, $ssh_key) = $c->fetchrow()) {
 }
 
 # Now write out the files
-write_array_file($file_dir."dumps/ssh_dump", @ssh_array);
+write_array_file($file_dir."/dumps/ssh_dump", @ssh_array);
