@@ -5,7 +5,7 @@
  * Copyright 2002 GForge, LLC
  * http://gforge.org/
  *
- * @version   $Id: view.php,v 1.4 2003/02/12 14:24:39 rspisser Exp $
+ * @version   $Id: view.php,v 1.6 2004/04/20 07:36:55 gsmet Exp $
  */
 
 
@@ -35,6 +35,9 @@ if ($docid) {
 	} elseif ($g->isError()) {
 		exit_error('Error',$g->getErrorMessage());
 	}
+	if(!$g->isPublic()) {
+		session_require(array('group' => $group_id));
+	}
 
 	$d = new Document($g,$docid);
 	if (!$d || !is_object($d)) {
@@ -43,7 +46,7 @@ if ($docid) {
 		exit_error('Error',$d->getErrorMessage());
 	}
 
-	Header ("Content-disposition: filename=".$d->getFileName());
+	Header ('Content-disposition: filename="'.str_replace('"', '', $d->getFileName()).'"');
 
 	if (strstr($d->getFileType(),'app')) {
 		Header ("Content-type: application/binary");
@@ -57,4 +60,4 @@ if ($docid) {
 	exit_error($Language->getText('docman_display_doc','no_document_data_title'),$Language->getText('docman_display_doc','no_document_data_text'));
 }
 
-?>
\ No newline at end of file
+?>
