@@ -8,7 +8,7 @@
   * Copyright 1999-2001 (c) VA Linux Systems
   * http://sourceforge.net
   *
-  * @version   $Id: rss_sfprojects.php,v 1.15 2001/06/22 15:10:04 dbrogdon Exp $
+  * @version   $Id: rss_sfprojects.php,v 1.3 2005/07/01 12:41:24 gsmet Exp $
   *
   */
 
@@ -34,7 +34,7 @@ $res = db_query("
 	AND 
 		status='A' 
     ORDER BY 
-		group_id",$limit);
+		group_id DESC",$limit);
 
 rss_dump_project_result_set($res,$GLOBALS['sys_name'].' Full Project Listing');
 ?>
