@@ -5,8 +5,8 @@
  * http://sourceforge.net
  *
  * @author		Tim Perdue <tperdue@valnux.com>
- * @version		$Id: HTML_Graphs.php,v 1.18 2001/06/07 20:47:04 dbrogdon Exp $
- * @date		$Date: 2001/06/07 20:47:04 $
+ * @version		$Id: HTML_Graphs.php,v 1.4 2004/10/08 21:38:26 gsmet Exp $
+ * @date		$Date: 2004/10/08 21:38:26 $
  *
  * Ryan T. Sammartino made several changes to make the output XHTML 1.0
  * Transitional.
@@ -15,8 +15,8 @@
 /*
 #######################################################################
 #
-#   $Source: /home/cvsroot/alexandria/www/include/HTML_Graphs.php,v $
-#	$Revision: 1.18 $
+#   $Source: /cvsroot/gforge/gforge/www/include/HTML_Graphs.php,v $
+#	$Revision: 1.4 $
 #   $State: Exp $
 #
 #      Revision 1.5  1998/11/05 06:15:52  pdavis
@@ -797,7 +797,7 @@ function horizontal_multisection_graph($names, $multi_rows, $colors, $vals, $add
 	for( $j=0;$j<$subbars_num;$j++ ) {
         	$width=$multi_rows[$j][$i];
                 if (!$additive) $width-=$prev_val;
-                if ($width<=0 && ($j!=$subbars_num-1 || shown)) continue;
+                if ($width<=0 && ($j!=$subbars_num-1 || $shown)) continue;
                 // make sure that we show at least stump, but only one
                 $shown=1;
                 $prev_val=$multi_rows[$j][$i];
