@@ -6,7 +6,7 @@
  * Copyright 1999-2001 (c) VA Linux Systems
  * http://sourceforge.net
  *
- * @version   $Id: html.php,v 1.390 2001/06/28 16:45:28 pfalcon Exp $
+ * @version   $Id: html.php,v 1.42.2.3 2005/10/17 13:08:19 danper Exp $
  */
 
 /**
@@ -15,10 +15,8 @@
  * @param		string	The feedback.
  */
 function html_feedback_top($feedback) {
-	if (!$feedback)
-		return '';
-	print '
-		<h3><span style="color:red">'.$feedback.'</span></h3>';
+	global $HTML;
+	echo $HTML->feedback($feedback);
 }
 
 /**
@@ -40,10 +38,8 @@ function make_user_link($username) {
  * @param		string	The feedback.
  */
 function html_feedback_bottom($feedback) {
-	if (!$feedback)
-		return '';
-	print '
-		<h3><span style="color:red">'.$feedback.'</span></h3>';
+	global $HTML;
+	echo $HTML->feedback($feedback);
 }
 
 /**
@@ -88,8 +84,7 @@ function html_dbimage($id, $args=0) {
  * @param		int 	height of the image
  * @param		array	Any <img> tag parameters (i.e. 'border', 'alt', etc...)
  */
-function html_abs_image($url, $width, $height, $args)
-{
+function html_abs_image($url, $width, $height, $args) {
 	$return = ('<img src="' . $url . '"');
 	reset($args);
 	while(list($k,$v) = each($args)) {
@@ -129,23 +124,49 @@ function html_image($src,$width,$height,$args,$display=1) {
 }
 
 /**
- * html_get_language_popup() - Pop up box of supported languages
+ * html_get_language_popup() - Pop up box of supported languages.
  *
- * @param		object	BaseLanguage object
- * @param		string	The title of the popup box
- * @param		string	Which element of the box is to be selected
+ * @param		object	BaseLanguage object.
+ * @param		string	The title of the popup box.
+ * @param		string	Which element of the box is to be selected.
+ * @return	string	The html select box.
  */
-function html_get_language_popup ($Language,$title='language_id',$selected='xzxzxz') {
+function html_get_language_popup ($Language,$title='language_id',$selected='xzxz') {
 	$res=$Language->getLanguages();
 	return html_build_select_box ($res,$title,$selected,false);
 }
 
 /**
- * html_get_timezone_popup() - Pop up box of supported Timezones
- * Assumes you have included Timezones array file
+ * html_get_theme_popup() - Pop up box of supported themes.
  *
- * @param		string	The title of the popup box
- * @param		string	Which element of the box is to be selected
+ * @param		string	The title of the popup box.
+ * @param		string	Which element of the box is to be selected.
+ * @return	string	The html select box.
+ */
+function html_get_theme_popup ($title='theme_id',$selected='xzxz') {
+	$res=db_query("SELECT theme_id, fullname FROM themes WHERE enabled=true");
+	return html_build_select_box($res,$title,$selected,false);
+}
+
+/**
+ * html_get_ccode_popup() - Pop up box of supported country_codes.
+ *
+ * @param		string	The title of the popup box.
+ * @param		string	Which element of the box is to be selected.
+ * @return	string	The html select box.
+ */
+function html_get_ccode_popup ($title='ccode',$selected='xzxz') {
+	$res=db_query("SELECT ccode,country_name FROM country_code ORDER BY country_name");
+	return html_build_select_box ($res,$title,$selected,false);
+}
+
+/**
+ * html_get_timezone_popup() - Pop up box of supported Timezones.
+ * Assumes you have included Timezones array file.
+ *
+ * @param		string	The title of the popup box.
+ * @param		string	Which element of the box is to be selected.
+ * @return	string	The html select box.
  */
 function html_get_timezone_popup ($title='timezone',$selected='xzxz') {
 	global $TZs;
@@ -156,15 +177,38 @@ function html_get_timezone_popup ($title='timezone',$selected='xzxz') {
 	return html_build_select_box_from_arrays ($TZs,$TZs,$title,$selected,false);
 }
 
+
+/**
+ * html_build_select_box_from_assoc() - Takes one assoc array and returns a pop-up box.
+ *
+ * @param	array	An array of items to use.
+ * @param	string	The name you want assigned to this form element.
+ * @param	string	The value of the item that should be checked.
+ * @param	boolean	Whether we should swap the keys / names.
+ * @param	bool	Whether or not to show the '100 row'.
+ * @param	string	What to call the '100 row' defaults to none.
+ */
+function html_build_select_box_from_assoc ($arr,$select_name,$checked_val='xzxz',$swap=false,$show_100=false,$text_100='None') {
+	if ($swap) {
+		$keys=array_values($arr);
+		$vals=array_keys($arr);
+	} else {
+		$vals=array_values($arr);
+		$keys=array_keys($arr);
+	}
+	return html_build_select_box_from_arrays ($keys,$vals,$select_name,$checked_val,$show_100,$text_100);
+}
+
 /**
  * html_build_select_box_from_array() - Takes one array, with the first array being the "id"
  * or value and the array being the text you want displayed.
  *
- * @param		string	The name you want assigned to this form element
- * @param		string	The value of the item that should be checked
+ * @param	array	An array of items to use.
+ * @param	string	The name you want assigned to this form element.
+ * @param	string	The value of the item that should be checked.
  */
 function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz',$samevals = 0) {
-	$return .= '
+	$return = '
 		<select name="'.$select_name.'">';
 
 	$rows=count($vals);
@@ -189,6 +233,73 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
 	return $return;
 }
 
+/**
+ * html_build_radio_buttons_from_arrays() - Takes two arrays, with the first array being the "id" or value and the other
+ * array being the text you want displayed.
+ *
+ * The infamous '100 row' has to do with the SQL Table joins done throughout all this code.
+ * There must be a related row in users, categories, et	, and by default that
+ * row is 100, so almost every pop-up box has 100 as the default
+ * Most tables in the database should therefore have a row with an id of 100 in it so that joins are successful
+ *
+ * @param		array	The ID or value
+ * @param		array	Text to be displayed
+ * @param		string	Name to assign to this form element
+ * @param		string	The item that should be checked
+ * @param		bool	Whether or not to show the '100 row'
+ * @param		string	What to call the '100 row' defaults to none
+ * @param		bool	Whether or not to show the 'Any row'
+ * @param		string	What to call the 'Any row' defaults to any
+ */
+function html_build_radio_buttons_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='none',$show_any=false,$text_any='any') {
+	global $Language;
+	if ($text_100=='none'){
+		$text_100=$Language->getText('include_html','none');
+	}
+	$return = '';
+
+	$rows=count($vals);
+	if (count($texts) != $rows) {
+		$return .= 'ERROR - uneven row counts';
+	}
+
+	//we don't always want the default Any row shown
+	if ($show_any) {
+		$return .= '
+		<input type="radio" name="'.$select_name.'" value=""'.(($checked_val=='') ? ' checked' : '').'>&nbsp;'. $text_any .'<br />';
+	}
+	//we don't always want the default 100 row shown
+	if ($show_100) {
+		$return .= '
+		<input type="radio" name="'.$select_name.'" value="100"'.(($checked_val==100) ? ' checked' : '').'>&nbsp;'. $text_100 .'<br />';
+	}
+
+	$checked_found=false;
+
+	for ($i=0; $i<$rows; $i++) {
+		//  uggh - sorry - don't show the 100 row
+		//  if it was shown above, otherwise do show it
+		if (($vals[$i] != '100') || ($vals[$i] == '100' && !$show_100)) {
+			$return .= '
+				<input type="radio" name="'.$select_name.'" value="'.$vals[$i].'"';
+			if ((string)$vals[$i] == (string)$checked_val) {
+				$checked_found=true;
+				$return .= ' checked';
+			}
+			$return .= '>&nbsp;'.htmlspecialchars($texts[$i]).'<br />';
+		}
+	}
+	//
+	//	If the passed in "checked value" was never "SELECTED"
+	//	we want to preserve that value UNLESS that value was 'xzxz', the default value
+	//
+	if (!$checked_found && $checked_val != 'xzxz' && $checked_val && $checked_val != 100) {
+		$return .= '
+		<input type="radio" value="'.$checked_val.'" checked>&nbsp;'.$Language->getText('include_html','no_change').'<br />';
+	}
+
+	return $return;
+}
 /**
  * html_build_select_box_from_arrays() - Takes two arrays, with the first array being the "id" or value and the other
  * array being the text you want displayed.
@@ -204,26 +315,37 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
  * @param		string	The item that should be checked
  * @param		bool	Whether or not to show the '100 row'
  * @param		string	What to call the '100 row' defaults to none
+ * @param		bool	Whether or not to show the 'Any row'
+ * @param		string	What to call the 'Any row' defaults to any
  */
-function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='none', $pos_100='top') {
+function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_val='xzxz',$show_100=true,$text_100='none',$show_any=false,$text_any='any') {
 	global $Language;
 	if ($text_100=='none'){
 		$text_100=$Language->getText('include_html','none');
 	}
-	$return .= '
-		<select name="'.$select_name.'">';
-
-	//we don't always want the default 100 row shown
-	if ($show_100 && $pos_100=='top') {
-		$return .= '
-		<option value="100">'. $text_100 .'</option>';
-	}
+	$return = '';
 
 	$rows=count($vals);
 	if (count($texts) != $rows) {
 		$return .= 'ERROR - uneven row counts';
 	}
 
+	$return .= '
+		<select name="'.$select_name.'">';
+
+	//we don't always want the default Any row shown
+	if ($show_any) {
+		$return .= '
+		<option value=""'.(($checked_val=='') ? ' SELECTED' : '').'>'. $text_any .'</option>';
+	}
+	//we don't always want the default 100 row shown
+	if ($show_100) {
+		$return .= '
+		<option value="100"'.(($checked_val==100) ? ' SELECTED' : '').'>'. $text_100 .'</option>';
+	}
+
+	$checked_found=false;
+
 	for ($i=0; $i<$rows; $i++) {
 		//  uggh - sorry - don't show the 100 row
 		//  if it was shown above, otherwise do show it
@@ -234,7 +356,7 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 				$checked_found=true;
 				$return .= ' selected="selected"';
 			}
-			$return .= '>'.htmlspecialchars($texts[$i]).'</option>';
+			$return .= '>'./*htmlspecialchars(*/$texts[$i]/*)*/.'</option>';
 		}
 	}
 	//
@@ -245,11 +367,6 @@ function html_build_select_box_from_arrays ($vals,$texts,$select_name,$checked_v
 		$return .= '
 		<option value="'.$checked_val.'" selected="selected">'.$Language->getText('include_html','no_change').'</option>';
 	}
-	if ($show_100 && $pos_100=='bottom') {
-		$return .= '
-		<option value="100">'. $text_100 .'</option>';
-	}
-
 
 	$return .= '
 		</select>';
@@ -277,7 +394,7 @@ function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=tr
  * html_build_multiple_select_box() - Takes a result set, with the first column being the "id" or value
  * and the second column being the text you want displayed.
  *
- * @param		int		The result set
+ * @param		int	The result set
  * @param		string	Text to be displayed
  * @param		string	The item that should be checked
  * @param		int		The size of this box
@@ -303,7 +420,6 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 	}
 
 	$rows=db_numrows($result);
-
 	for ($i=0; $i<$rows; $i++) {
 		if ((db_result($result,$i,0) != '100') || (db_result($result,$i,0) == '100' && !$show_100)) {
 			$return .= '
@@ -317,7 +433,61 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 					$return .= ' selected="selected"';
 				}
 			}
-			$return .= '>'.$val.'-'. substr(db_result($result,$i,1),0,35). '</option>';
+			$return .= '>'. substr(db_result($result,$i,1),0,35). '</option>';
+		}
+	}
+	$return .= '
+		</select>';
+	return $return;
+}
+
+/**
+ * html_build_multiple_select_box_from_arrays() - Takes two arrays and builds a multi-select box
+ *
+ * @param		array	id of the field  
+ * @param		array	Text to be displayed
+ * @param		string	id of the items selected
+ * @param		string	The item that should be checked
+ * @param		int		The size of this box
+ * @param		bool	Whether or not to show the '100 row'
+ */
+function html_build_multiple_select_box_from_arrays($ids,$texts,$name,$checked_array,$size='8',$show_100=true,$text_100='none') {
+	global $Language;
+	$checked_count=count($checked_array);
+	$return .='
+		<select name="'.$name.'" multiple="multiple" size="'.$size.'">';
+	if ($show_100) {
+		if ($text_100=='none') {
+			$text_100=$Language->getText('include_html','none');
+		}
+		/*
+			Put in the default NONE box
+		*/
+		$return .= '
+		<option value="100"';
+		for ($j=0; $j<$checked_count; $j++) {
+			if ($checked_array[$j] == '100') {
+				$return .= ' selected="selected"';
+			}
+		}
+		$return .= '>'.$text_100.'</option>';
+	}
+
+	$rows=count($ids);
+	for ($i=0; $i<$rows; $i++) {
+		if (( $ids[$i] != '100') || ($ids[$i] == '100' && !$show_100)) {
+			$return .=' 
+				<option value="'.$ids[$i].'"';
+			/*
+				Determine if it's checked
+			*/
+			$val=$ids[$i];
+			for ($j=0; $j<$checked_count; $j++) {
+				if ($val == $checked_array[$j]) {
+					$return .= ' selected="selected"';
+				}
+			}
+			$return .= '>'.$texts[$i].' </option>';
 		}
 	}
 	$return .= '
@@ -352,8 +522,8 @@ function html_get_priority_color ($index) {
 	$index = (int)$index;
 	if ($index<1) {
 		$index=1;
-	} else if ($index>9) {
-		$index=9;
+	} else if ($index>5) {
+		$index=5;
 	}
 	//return "prior$index";
 	return $bgpri[$index];
@@ -364,7 +534,7 @@ function html_get_priority_color ($index) {
  *
  * @see html_build_priority_select_box()
  */
-function build_priority_select_box ($name='priority', $checked_val='5', $nochange=false) {
+function build_priority_select_box ($name='priority', $checked_val='3', $nochange=false) {
 	echo html_build_priority_select_box ($name, $checked_val, $nochange);
 }
 
@@ -376,7 +546,7 @@ function build_priority_select_box ($name='priority', $checked_val='5', $nochang
  * @param		string	The value to be checked
  * @param		bool	Whether to make 'No Change' selected.
  */
-function html_build_priority_select_box ($name='priority', $checked_val='5', $nochange=false) {
+function html_build_priority_select_box ($name='priority', $checked_val='3', $nochange=false) {
 	global $Language;
 ?>
 	<select name="<?php echo $name; ?>">
@@ -387,11 +557,7 @@ function html_build_priority_select_box ($name='priority', $checked_val='5', $no
 	<option value="2"<?php if ($checked_val=="2") {echo " selected=\"selected\"";} ?>>2</option>
 	<option value="3"<?php if ($checked_val=="3") {echo " selected=\"selected\"";} ?>>3</option>
 	<option value="4"<?php if ($checked_val=="4") {echo " selected=\"selected\"";} ?>>4</option>
-	<option value="5"<?php if ($checked_val=="5") {echo " selected=\"selected\"";} ?>>5 - <?php echo $Language->getText('include_html','priority_medium') ?></option>
-	<option value="6"<?php if ($checked_val=="6") {echo " selected=\"selected\"";} ?>>6</option>
-	<option value="7"<?php if ($checked_val=="7") {echo " selected=\"selected\"";} ?>>7</option>
-	<option value="8"<?php if ($checked_val=="8") {echo " selected=\"selected\"";} ?>>8</option>
-	<option value="9"<?php if ($checked_val=="9") {echo " selected=\"selected\"";} ?>>9 - <?php echo $Language->getText('include_html','priority_highest') ?></option>
+	<option value="5"<?php if ($checked_val=="5") {echo " selected=\"selected\"";} ?>>5 - <?php echo $Language->getText('include_html','priority_highest') ?></option>
 	</select>
 <?php
 
@@ -484,8 +650,13 @@ function site_project_header($params) {
 		session_require(array('group'=>'1'));
 	}
 
+	$params['title']=$project->getPublicName().': '.$params['title'];
+
 	echo $HTML->header($params);
-	echo html_feedback_top($GLOBALS['feedback']);
+	
+	if(isset($GLOBALS['feedback'])) {
+		echo html_feedback_top($GLOBALS['feedback']);
+	}
 //	echo $HTML->project_tabs($params['toptab'],$params['group'],$params['tabtext']);
 }
 
@@ -499,7 +670,9 @@ function site_project_header($params) {
 function site_project_footer($params) {
 	GLOBAL $HTML;
 
-	echo html_feedback_bottom($GLOBALS['feedback']);
+	if(isset($GLOBALS['feedback'])) {
+		echo html_feedback_bottom($GLOBALS['feedback']);
+	}
 	echo $HTML->footer($params);
 }
 
@@ -517,21 +690,19 @@ function site_user_header($params) {
 		Check to see if logged in
 	*/
 	echo $HTML->header($params);
-	echo html_feedback_top($GLOBALS['feedback']);
-	echo ($HTML->BeginSubMenu());
-	echo ($HTML->PrintSubMenu(
+	echo html_feedback_top((isset($GLOBALS['feedback']) ? $GLOBALS['feedback'] : ''));
+	echo ($HTML->beginSubMenu());
+	echo ($HTML->printSubMenu(
 		array($Language->getText('menu','my_personal_page'),
 			$Language->getText('menu','diary_notes'),
 			$Language->getText('menu','account_maintenance'),
-			$Language->getText('menu','register_project'),
-			$Language->getText('menu','bookmark_page')),
-		array('"/my/"',
-			'"/my/diary.php"',
-			'"/account/"',
-			'"/register/"',
-			'"/my/bookmark_add.php"')));
+			$Language->getText('menu','register_project')),
+		array('/my/',
+			'/my/diary.php',
+			'/account/',
+			'/register/')));
 	plugin_hook ("usermenu", false) ;
-	echo ($HTML->EndSubMenu());
+	echo ($HTML->endSubMenu());
 }
 
 /**
@@ -543,7 +714,7 @@ function site_user_header($params) {
 function site_user_footer($params) {
 	GLOBAL $HTML;
 
-	echo html_feedback_bottom($GLOBALS['feedback']);
+	echo html_feedback_bottom((isset($GLOBALS['feedback']) ? $GLOBALS['feedback'] : ''));
 	echo $HTML->footer($params);
 }
 
