@@ -6,7 +6,7 @@
  * Copyright 1999-2001 (c) VA Linux Systems
  * http://sourceforge.net
  *
- * @version   $Id: squal_exit.php,v 1.6 2001/06/22 17:55:57 dbrogdon Exp $
+ * @version   $Id: squal_exit.php,v 1.1.1.2.10.1 2005/11/25 15:53:25 danper Exp $
  */
 
 /**
@@ -48,4 +48,11 @@ function exit_missing_param() {
 	exit_error('','MISSING REQUIRED PARAMETERS');
 }
 
+/**
+ * exit_disabled() - Return a 'Disabled Feature' error
+ */
+function exit_disabled() {
+       exit_error('','DISABLED FEATURE');
+}
+
 ?>
