@@ -6,7 +6,7 @@
  * Portions Copyright 1999-2001 (c) VA Linux Systems
  * The rest Copyright 2002 (c) Silicon and Software Systems (S3)
  *
- * @version   $Id$
+ * @version   $Id: viewprofile.php,v 1.5 2004/03/24 14:34:10 gsmet Exp $
  *
  */
 
@@ -14,6 +14,9 @@ require_once('pre.php');
 require_once('people_utils.php');
 require_once('skills_utils.php');
 
+if (!$sys_use_people) {
+	exit_disabled();
+}
 
 if ($user_id) {
 
@@ -60,4 +63,4 @@ if ($user_id) {
 	exit_error('Error','user_id not found.');
 }
 
-?>
+?>
\ No newline at end of file
