@@ -7,13 +7,13 @@
   * Copyright 1999-2001 (c) VA Linux Systems
   * http://sourceforge.net
   *
-  * @version   $Id: download.php,v 1.17 2001/05/22 16:12:12 pfalcon Exp $
+  * @version   $Id: download.php,v 1.3 2004/04/15 08:37:06 cbayle Exp $
   *
   */
 
 $no_gz_buffer=true;
 
-require_once('squal_pre.php');
+require_once('pre.php');
 
 $sql="SELECT * FROM snippet_version WHERE snippet_version_id='$id'";
 $result=db_query($sql);
