@@ -7,7 +7,7 @@
   * Copyright 1999-2001 (c) VA Linux Systems
   * http://sourceforge.net
   *
-  * @version   $Id: site_stats_utils.php,v 1.79 2001/05/22 15:47:25 pfalcon Exp $
+  * @version   $Id: site_stats_utils.php,v 1.12 2004/04/21 20:15:28 tom Exp $
   *
   */
 
@@ -367,7 +367,7 @@ function stats_site_projects_daily( $span ) {
 	if ( ($valid_days = db_numrows( $res )) > 1 ) {
 
 		?>
-		<p><strong><?php echo $Language->getText('stats_site_utils','statistics_for_the_past_days',array($GLOBALS['valid_days'])) ?>;</strong></p>
+		<p><strong><?php echo $Language->getText('stats_site_utils','statistics_for_the_past_days',array($valid_days)); ?></strong></p>
 
 		<p>
 		<table width="100%" cellpadding="0" cellspacing="0" border="0">
@@ -422,7 +422,7 @@ function stats_site_projects_monthly() {
 	if ( ($valid_months = db_numrows( $res )) > 1 ) {
 
 		?>
-		<p><strong><?php echo $Language->getText('stats_site_utils','statistics_for_the_past_months',array($GLOBALS['valid_months'])); ?>;</strong></p>
+		<p><strong><?php echo $Language->getText('stats_site_utils','statistics_for_the_past_months',array($valid_months)); ?></strong></p>
 
 		<p>
 		<table width="100%" cellpadding="0" cellspacing="0" border="0">
